@@ -13,6 +13,16 @@ from .model_shell import ModelShell
 
 # Note: reference for dunder methods: https://rszalski.github.io/magicmethods/
 
+IMMUTABLE_TYPES = (
+    str,
+    int,
+    float,
+    complex,
+    frozenset,
+    bool,
+    bytes,
+)
+
 MutableType = TypeVar("MutableType", bound="Mutable")
 
 
@@ -109,6 +119,11 @@ class Mutable(MutableBase):
         return session
 
     def __new__(cls, obj: Any = None, root: Mutable = None) -> Mutable:
+        if (obj is None or isinstance(obj, IMMUTABLE_TYPES)) and root is not None:
+            # immutable objects don't require mutation tracking
+            # so just return the immutable object
+            return obj
+
         if isinstance(obj, cls):
             obj.set_root(root)
             return obj
@@ -210,15 +225,27 @@ class Mutable(MutableBase):
             # note that this line assumes the item class's constructor can accept a
             # generator as its argument
             # if this is incorrect, you will have to overload the __setitem__ operator
-            self._object[key] = type(item)((Mutable(i, self.root) for i in item))
+            self._object[key] = type(item)((self._convert_item(i) for i in item))
         else:
-            self._object[key] = Mutable(item, self.root)
+            self._object[key] = self._convert_item(item)
         self._changed()
 
     def __delitem__(self, key):
         self._changed()
         del self._object[key]
 
+    def _convert_item(self, item, root=None):
+        """Convert an item to a mutable object for setitem and related operations.
+
+        Args:
+            item (Any): Item to convert.
+            root (Mutable, optional). Root mutable object. Defaults to None.
+
+        Returns:
+            Mutable: Converted item.
+        """
+        return Mutable(item, root or self.root)
+
     def __repr__(self):
         return (
             f"<Mutable {repr(self._object)}>"
@@ -483,8 +510,7 @@ class Mutable(MutableBase):
         """
         return hasattr(self._object, "__table__")
 
-    @staticmethod
-    def convert_object(obj: Any, root: Mutable) -> Any:
+    def convert_object(self, obj: Any, root: Mutable) -> Any:
         """Convert an object before wrapping it in the mutable class.
 
         Note that this method simply returns the object. Subclasses will likely
@@ -505,7 +531,20 @@ class Mutable(MutableBase):
         Returns:
             Any: The original object.
         """
-        return self._object
+        return self._get_object(self._object)
+
+    def _get_object(self, obj: Any = None) -> Any:
+        """Return the original object wrapped in the mutable class.
+
+        Args:
+            obj (Any, optional): Object to get. The object may be wrapped in the mutable
+                class. If None, this method returns the object wrapped by ``self``.
+                Defaults to None.
+
+        Returns:
+            Any: The original object.
+        """
+        return obj.get_object() if isinstance(obj, Mutable) else obj
 
     def get_tracked_children(self) -> List[Mutable]:
         """Get the "children" (attributes and items) tracked by the mutable wrapper.
