@@ -12,11 +12,10 @@ from .mutable import Mutable
 class MutableTuple(Mutable):
     """Mutable wrapper for tuples.
 
-    Subclasses :class:`Mutable`.
+    Subclasses :class:`sqlalchemy_mutable.Mutable`.
     """
 
-    @staticmethod
-    def convert_object(obj: Iterable, root: Mutable) -> Tuple:
+    def convert_object(self, obj: Iterable, root: Mutable) -> Tuple:
         """Convert an object into a mutable tuple.
 
         Args:
@@ -29,7 +28,7 @@ class MutableTuple(Mutable):
         return (
             tuple()
             if obj is None
-            else tuple((Mutable(item, root) for item in tuple(obj)))
+            else tuple((self._convert_item(item, root) for item in tuple(obj)))
         )
 
     def get_object(self) -> Tuple:
@@ -38,7 +37,7 @@ class MutableTuple(Mutable):
         Returns:
             Tuple: Shallow copy of the tuple.
         """
-        return tuple((item.get_object() for item in self._object))
+        return tuple((self._get_object(item) for item in self._object))
 
     def get_tracked_items(self) -> List[Mutable]:
         """Get the list of items whose mutations are being tracked.
@@ -46,4 +45,4 @@ class MutableTuple(Mutable):
         Returns:
             List[Mutable]: Tracked items.
         """
-        return list(self)
+        return list([item for item in self._object if isinstance(item, Mutable)])
